beamprofiler.niso.characterizing\_parameters.clip\_level\_beam\_width
=====================================================================

.. currentmodule:: beamprofiler.niso.characterizing_parameters

.. autofunction:: clip_level_beam_width